from gtkeasyapp.easyprocess import *
from devicemanager.gpsmanager import *


##GpsProcess
##Read every timeout data from GPS device and send it to callback
class GpsProcess(EasyProcess):
	##Constructor
	##@param processName : name of the process
	##@param ui : EasyWindow instance
	##@param onFix : on gps fix callback
	def __init__(self, processName, ui, onFix):
		#super constructor
		EasyProcess.__init__(self, processName, ui)
	
		#set members
		self.__onFix = onFix
		self.__gps = GpsManager()
		self._timeout = 60.0 #check GPS device every 60 seconds
		self.__started = False
		
		#custom process
		self.custom(delayedTime=2.0)
		
	
	##Process : start GPS if not started
	def _process(self):
		if not self.__started:
			#start GPS device
			self.__startGps()
			
			
	##Stopping process
	def _stopping(self):
		#stop GPS device
		if self.__gps!=None:
			self.__gps.stop()
			self.__started = False
			
	
	##Get GPS device data
	def getData(self):
		if self.__started:
			#return data
			return self.__gps.getData()
		
		else:
			#GPS not started yet
			return None
	
	
	##Start GPS device
	def __startGps(self):
		try:
			#start gps
			self.__gps.start(self.__gpsStarted, None, self.__onFix)
				
		except GpsManagerException, e:
			#unable to start GPS
			print 'GpsProcess::__startGps : GpsManagerException : %s' % str(e)
			
			
	##GPS started
	def __gpsStarted(self):
		self.__started = True